==> bce-java-sdk-0.10.28-sources.jar: com/baidubce/services/cdn/model/SetDomainLimitRateRequest.java <==
/*
 * Copyright 2016 Baidu, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */

package com.baidubce.services.cdn.model;

import com.baidubce.auth.BceCredentials;
import com.baidubce.model.AbstractBceRequest;
import com.baidubce.util.JsonUtils;
import com.fasterxml.jackson.core.JsonProcessingException;

/**
 * @author yixing
 *
 */
public class SetDomainLimitRateRequest extends AbstractBceRequest {
    private String domain;
    private int limitRate;

    /**
     * @return domain
     */
    public String getDomain() {
        return domain;
    }

    /**
     * @param domain the domain name
     */
    public void setDomain(String domain) {
        this.domain = domain;
    }

    /**
     * @return limitRate
     */
    public int getLimitRate() {
        return limitRate;
    }

    /**
     * @param limitRate
     */
    public void setLimitRate(int limitRate) {
        this.limitRate = limitRate;
    }
    
    /**
     * @param domain the domain name
     * @return returns this object
     */
    public SetDomainLimitRateRequest withDomain(String domain) {
        setDomain(domain);
        return this;
    }
    
    /**
     * @param limitRate
     * @return returns this object
     */
    public SetDomainLimitRateRequest withLimitRate(int limitRate) {
        setLimitRate(limitRate);
        return this;
    }
    
    /**
     * (non-Javadoc)
     * @see com.baidubce.model.AbstractBceRequest#withRequestCredentials(com.baidubce.auth.BceCredentials)
     */
    @Override
    public SetDomainLimitRateRequest withRequestCredentials(BceCredentials credentials) {
        this.setRequestCredentials(credentials);
        return this;
    }
    
    /**
     * (non-Javadoc)
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        try {
            return JsonUtils.toJsonPrettyString(this);
        } catch (JsonProcessingException e) {
            return "";
        }
    }
}

==> bce-java-sdk-0.10.157-sources.jar: com/baidubce/services/cdn/model/SetDomainLimitRateRequest.java <==
/*
 * Copyright 2016 Baidu, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */

package com.baidubce.services.cdn.model;

import com.baidubce.auth.BceCredentials;
import com.baidubce.model.AbstractBceRequest;
import com.baidubce.util.JsonUtils;
import com.fasterxml.jackson.core.JsonProcessingException;

/**
 * @author yixing
 *
 */
public class SetDomainLimitRateRequest extends AbstractBceRequest {
    private String domain;
    private int limitRate;

    /**
     * @return domain
     */
    public String getDomain() {
        return domain;
    }

    /**
     * @param domain the domain name
     */
    public void setDomain(String domain) {
        this.domain = domain;
    }

    /**
     * @return limitRate
     */
    public int getLimitRate() {
        return limitRate;
    }

    /**
     * @param limitRate
     */
    public void setLimitRate(int limitRate) {
        this.limitRate = limitRate;
    }
    
    /**
     * @param domain the domain name
     * @return returns this object
     */
    public SetDomainLimitRateRequest withDomain(String domain) {
        setDomain(domain);
        return this;
    }
    
    /**
     * @param limitRate
     * @return returns this object
     */
    public SetDomainLimitRateRequest withLimitRate(int limitRate) {
        setLimitRate(limitRate);
        return this;
    }
    
    /**
     * (non-Javadoc)
     * @see com.baidubce.model.AbstractBceRequest#withRequestCredentials(com.baidubce.auth.BceCredentials)
     */
    @Override
    public SetDomainLimitRateRequest withRequestCredentials(BceCredentials credentials) {
        this.setRequestCredentials(credentials);
        return this;
    }

    /**
     * (non-Javadoc)
     * @see Object#toString()
     */
    @Override
    public String toString() {
        try {
            return JsonUtils.toJsonPrettyString(this);
        } catch (JsonProcessingException e) {
            return "";
        }
    }
}
